.. image:: https://img.shields.io/pypi/v/puglang.svg
  :alt: PyPI-Server
  :target: https://pypi.org/project/puglang/

.. image:: https://coveralls.io/repos/github/puglang/pug/badge.svg
   :alt: Coveralls
   :target: https://coveralls.io/github/puglang/pug

.. image:: https://readthedocs.org/projects/puglang/badge/?version=latest
  :alt: ReadTheDocs
  :target: https://puglang.readthedocs.io/en/stable/

.. image:: https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold
    :alt: Project generated with PyScaffold
    :target: https://pyscaffold.org/

.. image:: https://raw.githubusercontent.com/puglang/pug/main/img/pug-logo.png

|

=======
puglang
=======


    Pug Programming Language


Pug is a general purpose programming language.

.. _pyscaffold-notes:

Making Changes & Contributing
=============================

This project uses `pre-commit`_, please make sure to install it before making any
changes::

    pip install pre-commit
    cd puglang
    pre-commit install

It is a good idea to update the hooks to the latest version::

    pre-commit autoupdate

Don't forget to tell your contributors to also install and use pre-commit.

.. _pre-commit: https://pre-commit.com/

Note
====

This project has been set up using PyScaffold 4.2.1. For details and usage
information on PyScaffold see https://pyscaffold.org/.
